@@ -1,5 +1,7 @@
 # Django
+from django.contrib.postgres.fields import JSONField
 from django.db import models
+from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
 
 # Standard Library
@@ -108,6 +110,11 @@ class AbstractOrganization(models.Model):
         else:
             return self.name
 
+    def get_absolute_url(self):
+        return reverse(
+            "squarelet_auth_organizations:profile", kwargs={"slug": self.slug}
+        )
+
     @property
     def display_name(self):
         """Display 'Personal Account' for individual organizations"""
@@ -203,8 +210,7 @@ class Plan(models.Model):
 
     name = models.CharField(_("name"), max_length=255, unique=True)
     slug = models.SlugField(_("slug"), max_length=255, unique=True)
-
-    # XXX JSON resource field?
+    resources = JSONField(default=dict)
 
     def __str__(self):
         return self.name
